@@ -11,6 +11,7 @@
 #define MOBI_DECOMPRESSOR_H
 
 #include <QByteArray>
+#include <memory>
 namespace Mobipocket {
 
 class PDB;
@@ -22,7 +23,7 @@ public:
     virtual ~Decompressor() {}
     bool isValid() const { return valid; }
 
-    static Decompressor* create(quint8 type, const PDB& pdb);
+    static std::unique_ptr<Decompressor> create(quint8 type, const PDB& pdb);
 protected:
     const PDB& pdb;
     bool valid;
